﻿#include <QDebug>
#include "bridge.h"
#include "editor.h"
#include "tools.h"
#include "../common/sources/Map.h"

CBridge     bridge;

//---------------------------------------------------------------------------------------------
CBridge::CBridge(QObject *parent) : QObject(parent)
{
    // valeurs par défaut
    mMapSize = CVec2(15, 10);
    mMousePos = CVec2(-1, -1);
    leftPressing = false;
    leftPressed = false;
    rightPressed = false;
    mTabIndex = eTabMap;
    mTool = eQMLToolDraw;
    set_tileSelScrollVis(false);
    set_wallSelScrollVis(false);
    set_objectSelScrollVis(false);
    set_rectSelScrollVis(false);
}

void    CBridge::setMapWidth(qint32 valeur)
{
    mMapSize.x = valeur;
}

void    CBridge::setMapHeight(qint32 valeur)
{
    mMapSize.y = valeur;
}

void    CBridge::setMouse(qint32 x, qint32 y)
{
    leftPressing = false;
    mMousePos = CVec2(x, y);

    editor.useTool();
    updateQMLImage();
}

void    CBridge::setMousePress(qint32 button)
{
    leftPressing = false;

    if (button == Qt::LeftButton)
    {
        leftPressing = true;
        leftPressed = true;
    }
    else if (button == Qt::RightButton)
        rightPressed = true;

    editor.useTool();
    updateQMLImage();
}

void    CBridge::setMouseRelease(qint32 button)
{
    leftPressing = false;

    if (button == Qt::LeftButton)
        leftPressed = false;
    else if (button == Qt::RightButton)
        rightPressed = false;

    editor.useTool();
    updateQMLImage();
}

void CBridge::setTabIndex(qint32 index)
{
    editor.unselect();
    mTabIndex = (ETabIndex)index;
}

void    CBridge::resizeMap()
{
    editor.unselect();
    map.mSize = mMapSize;
    map.resize();
    updateQMLImage();
}

void    CBridge::save(QString fileName)
{
    // [8] pour retirer "file:///"
    map.save(&fileName.toLocal8Bit().data()[8]);
}

void    CBridge::load(QString fileName)
{
    // [8] pour retirer "file:///"
    map.load(&fileName.toLocal8Bit().data()[8]);
    updateQMLImage();
}

void    CBridge::undo()
{
    editor.mUndoStack->undo();
}

void    CBridge::redo()
{
    editor.mUndoStack->redo();
}

void    CBridge::setTool(qint32 tool)
{
    mTool = (EQMLTools)tool;
    updateQMLImage();
}

void    CBridge::copy()
{
    editor.toolCopy();
}

void    CBridge::cut()
{
    editor.toolCut();
}

void    CBridge::setSelTileType(qint32 type)
{
    drawTileTool*   tool = new drawTileTool();

    if (tool->init(editor.mSelectStart, type) == true)
        editor.mUndoStack->push(tool);
    else
        delete tool;
}

void    CBridge::setSelWallType(qint32 type)
{
    drawWallTool*   tool = new drawWallTool();

    if (tool->init(editor.mSelectStart, type) == true)
        editor.mUndoStack->push(tool);
    else
        delete tool;
}

//---------------------------------------------------------------------------------------------
MyImageProvider::MyImageProvider() : QQuickImageProvider(QQuickImageProvider::Image)
{
}

QImage MyImageProvider::requestImage(const QString &/*id*/, QSize *size, const QSize &/*requestedSize*/)
{
    QImage image = editor.displayMap(map, bridge.mMousePos, bridge.mTabIndex);

    if (size != NULL)
        *size = QSize(image.width(), image.height());

    return image;
}
