﻿#include "game.h"
#include "walls.h"
#include "player.h"
#include "../common/sources/system/fileCache.h"
#include "../common/sources/system/cgraphics2d.h"
#include <QDebug>

#define SCREEN_WIDTH    320
#define SCREEN_HEIGHT   200

CGame   game;

void CGame::drawWall(QImage* image, CVec2 tablePos, EWallSide side)
{
    const char* fileName = walls.getFilename(tablePos, side);

    if (fileName[0] != 0)
    {
        QImage  wallGfx = fileCache.getImage(fileName);
        CVec2 gfxPos = walls.getGfxPos(tablePos, side);
        graph2D.drawImage(image, gfxPos, wallGfx);
    }
}

QImage CGame::displayMainView()
{
    QImage image(SCREEN_WIDTH,
                 SCREEN_HEIGHT,
                 QImage::Format_RGBA8888);

	// efface l'écran
    image.fill(QColor(0, 0, 0));

	// dessine le sol et le plafond
    QImage  floorGfx = fileCache.getImage("gfx/3DView/Floor.png");
    QImage  ceilingGfx = fileCache.getImage("gfx/3DView/Ceiling.png");

    graph2D.drawImage(&image, CVec2(0, 33), ceilingGfx);
    graph2D.drawImage(&image, CVec2(0, 72), floorGfx);

	// dessine les murs
    CVec2   tablePos;
    CVec2   localPos;
    CVec2   mapPos;
    EWallSide   side;
    CTile*  tile;

    for (int y = 0; y < WALL_TABLE_HEIGHT; ++y)
        for (int x = 0; x < WALL_TABLE_WIDTH; ++x)
        {
            tablePos = walls.getDrawSequence(CVec2(x, y));
            localPos = walls.getMapPos(tablePos);
            mapPos = player.getPosFromLocal(localPos);
            tile = map.getTile(mapPos);

            if (tile != NULL)
            {
                side = player.getWallSide(eWallSideUp);
                if (tile->mWalls[side].mType != 0)
                    drawWall(&image, tablePos, eWallSideUp);

                side = player.getWallSide(eWallSideLeft);
                if (tile->mWalls[side].mType != 0)
                    drawWall(&image, tablePos, eWallSideLeft);

                side = player.getWallSide(eWallSideRight);
                if (tile->mWalls[side].mType != 0)
                    drawWall(&image, tablePos, eWallSideRight);

                // objects.draw();
                // monsters.draw();
            }
        }

    return image;
}
